@@ -17,6 +17,15 @@ test_set_by_user() {
     assertTrue "Log file was not created" "[ -f $WORKON_HOME/logs/hook.log ]"
 }
 
+test_file_permissions() {
+    export VIRTUALENVWRAPPER_LOG_DIR="$WORKON_HOME/logs"
+    mkdir -p "$VIRTUALENVWRAPPER_LOG_DIR"
+    source "$test_dir/../virtualenvwrapper.sh"
+    perms=$(ls -l "$WORKON_HOME/logs/hook.log" | cut -f1 -d' ')
+    #echo $perms
+    assertTrue "Log file permissions are wrong: $perms" "echo $perms | grep '^-rw-rw'"
+}
+
 test_not_set_by_user() {
     unset WORKON_HOME
     unset VIRTUALENVWRAPPER_LOG_DIR
