@@ -22,7 +22,7 @@ setUp () {
 }
 
 test_get_site_packages_dir () {
-    mkvirtualenv "lssitepackagestest"
+    mkvirtualenv "lssitepackagestest" >/dev/null 2>&1
     d=$(virtualenvwrapper_get_site_packages_dir)
     echo "site-packages in $d"
     assertTrue "site-packages dir $d does not exist" "[ -d $d ]"
@@ -30,7 +30,7 @@ test_get_site_packages_dir () {
 }
 
 test_lssitepackages () {
-    mkvirtualenv "lssitepackagestest"
+    mkvirtualenv "lssitepackagestest" >/dev/null 2>&1
     contents="$(lssitepackages)"    
     actual=$(echo $contents | grep easy-install.pth)
     expected=$(echo $contents)
@@ -39,7 +39,7 @@ test_lssitepackages () {
 }
 
 test_lssitepackages_add2virtualenv () {
-    mkvirtualenv "lssitepackagestest"
+    mkvirtualenv "lssitepackagestest" >/dev/null 2>&1
     parent_dir=$(dirname $(pwd))
     base_dir=$(basename $(pwd))
     add2virtualenv "../$base_dir"
